@@ -217,6 +217,12 @@ When in dev mode Solara will:
     default=settings.ssg.enabled,
     help="(pre) Render static pages.",
 )
+@click.option(
+    "--search/--no-search",
+    is_flag=True,
+    default=settings.search.enabled,
+    help="Enable search (requires ssg generated pages).",
+)
 def run(
     app,
     host,
@@ -241,8 +247,11 @@ def run(
     theme_variant: settings.ThemeVariant,
     theme_variant_user_selectable: bool,
     ssg: bool,
+    search: bool,
 ):
+    """Run a Solara app."""
     settings.ssg.enabled = ssg
+    settings.search.enabled = search
     reload_dirs = reload_dirs if reload_dirs else None
     url = f"http://{host}:{port}"
 
@@ -310,7 +319,7 @@ def run(
     settings.theme.variant_user_selectable = theme_variant_user_selectable
     settings.main.tracer = tracer
     settings.main.timing = timing
-    for item in "theme_variant_user_selectable theme_variant theme_loader use_pdb server open_browser open url failed dev tracer timing ssg".split():
+    for item in "theme_variant_user_selectable theme_variant theme_loader use_pdb server open_browser open url failed dev tracer timing ssg search".split():
         del kwargs[item]
 
     def start_server():
@@ -327,7 +336,11 @@ def run(
                 from uvicorn.supervisors import ChangeReload
 
                 ChangeReload(
-                    config, target=run_with_settings(server, main=settings.main.dict(), theme=settings.theme.dict(), ssg=settings.ssg.dict()), sockets=[sock]
+                    config,
+                    target=run_with_settings(
+                        server, main=settings.main.dict(), theme=settings.theme.dict(), ssg=settings.ssg.dict(), search=settings.search.dict()
+                    ),
+                    sockets=[sock],
                 ).run()
             else:
                 server.run()
@@ -343,11 +356,21 @@ def run(
             base_url = f"http://{server.config.host}:{server.config.port}"
             rprint("Running Static Site Generator pre-render background task")
             ssg_crawl(base_url)
+            if settings.search.enabled:
+                from solara_enterprise.search.index import build_index
+
+                build_index("")
 
     # in dev mode we run the ssg in the child process (see run_with_settings)
     if not dev and settings.ssg.enabled:
         threading.Thread(target=ssg_run, daemon=True).start()
 
+    # if we don't have to wait for SSG, we can build the index right away
+    if not settings.ssg.enabled and settings.search.enabled:
+        from solara_enterprise.search.index import build_index
+
+        build_index("")
+
     start_server()
 
     # TODO: if we want to use webview, it should be sth like this
@@ -370,6 +393,7 @@ def run(
     help="Show browser window if true.",
 )
 def ssg(app: str, port: int, host: str, headed: bool):
+    """Static site generation"""
     settings.ssg.headed = headed
     settings.ssg.enabled = True
     os.environ["SOLARA_APP"] = app
@@ -384,14 +408,35 @@ def ssg(app: str, port: int, host: str, headed: bool):
     ssg_crawl(base_url)
 
 
+@cli.command()
+def deploy():
+    rprint("...")
+    import time
+
+    time.sleep(1)
+    rprint("Want your app to run instantly on awesomeapp-mystartup-gh.solara.run?")
+    rprint("\tCheck out https://solara.dev/docs/deploying/cloud-hosted")
+
+
+@cli.command()
+@click.argument("app")
+def search(app: str):
+    """Build search index based on ssg output"""
+    os.environ["SOLARA_APP"] = app
+    from solara_enterprise.search.index import build_index
+
+    build_index("")
+
+
 class run_with_settings:
     """This cross a process boundry, and takes the serialized settings with it"""
 
-    def __init__(self, server: uvicorn.Server, main: typing.Dict, theme: typing.Dict, ssg: typing.Dict):
+    def __init__(self, server: uvicorn.Server, main: typing.Dict, theme: typing.Dict, ssg: typing.Dict, search: typing.Dict):
         self.server = server
         self.main = main
         self.theme = theme
         self.ssg = ssg
+        self.search = search
 
     def __call__(self, *args, **kwargs):
         # this is now in the new process, where we need to re-apply the settings
@@ -405,10 +450,15 @@ class run_with_settings:
                 base_url = f"http://{self.server.config.host}:{self.server.config.port}"
                 rprint("Running Static Site Generator pre-render background task")
                 ssg_crawl(base_url)
+                if settings.search.enabled:
+                    from solara_enterprise.search.index import build_index
+
+                    build_index("")
 
         settings.main = settings.MainSettings(**self.main)
         settings.theme = settings.ThemeSettings(**self.theme)
         settings.ssg = settings.SSG(**self.ssg)
+        settings.search = settings.Search(**self.search)
         if settings.ssg.enabled:
             threading.Thread(target=ssg_run, daemon=True).start()
         try:
@@ -421,6 +471,7 @@ class run_with_settings:
 @cli.command()
 @click.option("--port", default=int(os.environ.get("PORT", 8000)))
 def staticserve(port):
+    """Experimental static serving"""
     import http.server
     import os
     from functools import partial
@@ -446,9 +497,9 @@ def staticbuild():
     target_dir = Path("staticbuild")
     target_dir.mkdir(exist_ok=True)
 
-    from .server import cdn_helper
+    from .server import settings
 
-    copytree(cdn_helper.default_cache_dir, target_dir / "_solara/cdn/")
+    copytree(settings.assets.proxy_cache_dir, target_dir / "_solara/cdn/")
 
     static_dir_target = target_dir / "static"
     static_dir_target.mkdir(exist_ok=True)
@@ -505,6 +556,7 @@ def staticbuild():
 
 @click.group()
 def create():
+    """Quickly create a solara script or project."""
     pass
 
 
@@ -516,6 +568,7 @@ def create():
     required=False,
 )
 def button(target: typing.Optional[Path]):
+    """Create a button with a click counter."""
     write_script("button", target)
 
 
@@ -527,6 +580,7 @@ def button(target: typing.Optional[Path]):
     required=False,
 )
 def markdown(target: typing.Optional[Path] = None):
+    """Create a markdown editor."""
     write_script("markdown", target)
 
 
@@ -566,6 +620,7 @@ def copytree(src: Path, dst: Path, copy_function=shutil.copy2, ignore: typing.Ca
     required=False,
 )
 def portal(target: Path):
+    """Create a full Python project template for a data portal"""
     target = Path(target)
     name = target.name
     package_name = name.replace("-", "_")
