@@ -4,6 +4,12 @@ from .style import Style  # noqa: F401 F403
 from .misc import *  # noqa: #F401 F403
 from .alert import Warning, Info, Error, Success  # noqa: #F401 F403
 from .checkbox import Checkbox  # noqa: #F401 F403
+from .cross_filter import (  # noqa: F401
+    CrossFilterDataFrame,
+    CrossFilterReport,
+    CrossFilterSelect,
+    CrossFilterSlider,
+)
 from .datatable import DataTable, DataFrame  # noqa: #F401 F403
 from .details import Details  # noqa: #F401 F403
 from .file_browser import FileBrowser  # noqa: #F401 F403
@@ -31,7 +37,7 @@ from .pivot_table import PivotTableView, PivotTable, PivotTableCard  # noqa: #F4
 from .head import Head  # noqa: #F401 F403
 from .title import Title  # noqa: #F401 F403
 from .link import Link  # noqa: #F401 F403
-from .applayout import AppLayout, Sidebar  # noqa: #F401 F403
+from .applayout import AppLayout, Sidebar, AppBar  # noqa: #F401 F403
 from .tab_navigation import TabNavigation  # noqa: #F401 F403
 from .markdown_editor import MarkdownEditor  # noqa: #F401 F403
 from .select import Select, SelectMultiple  # noqa: #F401 F403
@@ -41,6 +47,7 @@ from .figure_altair import FigureAltair, AltairChart  # noqa: #F401 F403
 from .meta import Meta  # noqa: #F401 F403
 from .columns import Columns, ColumnsResponsive  # noqa: #F401 F403
 from .file_drop import FileDrop  # noqa: #F401 F403
+from .file_download import FileDownload  # noqa: #F401 F403
 
 
 import reacton.core
