@@ -1,7 +1,7 @@
 import hashlib
 import logging
 import textwrap
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Union
 
 import ipyvuetify as v
 import pygments
@@ -11,6 +11,7 @@ from pygments.formatters import HtmlFormatter
 from pygments.lexers import get_lexer_by_name
 
 import solara
+import solara.components.applayout
 
 logger = logging.getLogger(__name__)
 
@@ -26,7 +27,7 @@ def _run_solara(code):
         app = local_scope["app"]
     elif "Page" in local_scope:
         Page = local_scope["Page"]
-        app = Page()
+        app = solara.components.applayout._AppLayoutEmbed(children=[Page()])
     else:
         raise NameError("No Page of app defined")
     box = v.Html(tag="div")
@@ -39,11 +40,13 @@ def _run_solara(code):
     )
 
 
-def _markdown_template(html):
+def _markdown_template(html, style=""):
     return (
         """
 <template>
-    <div class="solara-markdown rendered_html jp-RenderedHTMLCommon">"""
+    <div class="solara-markdown rendered_html jp-RenderedHTMLCommon" style=\""""
+        + style
+        + """\">"""
         + html
         + """</div>
 </template>
@@ -143,7 +146,7 @@ def MarkdownIt(md_text: str, highlight: List[int] = [], unsafe_solara_execute: b
 
 
 @solara.component
-def Markdown(md_text: str, unsafe_solara_execute=False):
+def Markdown(md_text: str, unsafe_solara_execute=False, style: Union[str, Dict, None] = None):
     """Renders markdown text
 
     Renders markdown using https://python-markdown.github.io/
@@ -153,45 +156,50 @@ def Markdown(md_text: str, unsafe_solara_execute=False):
      * `md_text`: The markdown text to render
      * `unsafe_solara_execute`: If True, code marked with language "solara" will be executed. This is potentially unsafe
         if the markdown text can come from user input and should only be used for trusted markdown.
+     * `style`: A string or dict of css styles to apply to the rendered markdown.
 
     """
     import markdown
 
     md_text = textwrap.dedent(md_text)
+    style = solara.util._flatten_style(style)
 
-    def highlight(src, language, *args, **kwargs):
-        try:
-            return _highlight(src, language, unsafe_solara_execute, *args, **kwargs)
-        except Exception as e:
-            logger.exception("Error highlighting code: %s", src)
-            return repr(e)
+    def make_markdown_object():
+        def highlight(src, language, *args, **kwargs):
+            try:
+                return _highlight(src, language, unsafe_solara_execute, *args, **kwargs)
+            except Exception as e:
+                logger.exception("Error highlighting code: %s", src)
+                return repr(e)
 
-    html = markdown.markdown(  # type: ignore
-        md_text,
-        extensions=[
-            "pymdownx.highlight",
-            "pymdownx.superfences",
-            "pymdownx.emoji",
-            "toc",  # so we get anchors for h1 h2 etc
-        ],
-        extension_configs={
-            "pymdownx.superfences": {
-                "custom_fences": [
-                    {
-                        "name": "mermaid",
-                        "class": "mermaid",
-                        "format": pymdownx.superfences.fence_div_format,
-                    },
-                    {
-                        "name": "solara",
-                        "class": "",
-                        "format": highlight,
-                    },
-                ],
+        return markdown.Markdown(  # type: ignore
+            extensions=[
+                "pymdownx.highlight",
+                "pymdownx.superfences",
+                "pymdownx.emoji",
+                "toc",  # so we get anchors for h1 h2 etc
+            ],
+            extension_configs={
+                "pymdownx.superfences": {
+                    "custom_fences": [
+                        {
+                            "name": "mermaid",
+                            "class": "mermaid",
+                            "format": pymdownx.superfences.fence_div_format,
+                        },
+                        {
+                            "name": "solara",
+                            "class": "",
+                            "format": highlight,
+                        },
+                    ],
+                },
             },
-        },
-    )
+        )
+
+    md = solara.use_memo(make_markdown_object, dependencies=[unsafe_solara_execute])
+    html = md.convert(md_text)
     # if we update the template value, the whole vue tree will rerender (ipvue/ipyvuetify issue)
     # however, using the hash we simply generate a new widget each time
     hash = hashlib.sha256((html + str(unsafe_solara_execute)).encode("utf-8")).hexdigest()
-    return v.VuetifyTemplate.element(template=_markdown_template(html)).key(hash)
+    return v.VuetifyTemplate.element(template=_markdown_template(html, style)).key(hash)
