@@ -53,6 +53,7 @@ nbextensions_ignorelist = [
     "execute_time/ExecuteTime",
     "dominocode/extension",
     "low-code-assistant/extension",
+    "domino-code-assist/extension",
     "jupyter-js/extension",
     "jupyter-js-widgets/extension",
     "jupyter_dash/main",
@@ -233,6 +234,12 @@ def read_root(path: str, root_path: str = "", render_kwargs={}, use_nbextensions
             pre_rendered_metas = "\n    ".join(ssg_data["metas"])
             title = ssg_data["title"]
 
+    if settings.assets.proxy:
+        # solara acts as a proxy
+        cdn = f"{root_path}/_solara/cdn"
+    else:
+        cdn = settings.assets.cdn
+
     render_settings = {
         "title": title,
         "path": path,
@@ -243,6 +250,8 @@ def read_root(path: str, root_path: str = "", render_kwargs={}, use_nbextensions
         "pre_rendered_html": pre_rendered_html,
         "pre_rendered_css": pre_rendered_css,
         "pre_rendered_metas": pre_rendered_metas,
+        "assets": settings.assets.dict(),
+        "cdn": cdn,
         **render_kwargs,
     }
     response = template.render(**render_settings)
