@@ -11,5 +11,5 @@ def Hero(title, sub_title, button_text):
                     rv.Html(tag="h1", children=[title], class_="mb-4"),
                     solara.HTML(tag="div", unsafe_innerHTML=f"<h2>{sub_title}</h2>", class_="mb-4"),
                     with solara.Link("/docs/quickstart"):
-                        solara.Button(label=button_text, elevation=0, large=True, class_="btn-size--xlarge")
+                        solara.Button(label=button_text, elevation=0, large=True, class_="btn-size--xlarge solara-docs-button")
     return main
