@@ -47,15 +47,17 @@ def Sidebar():
         with List():
             for route in all_routes:
                 if route.children and route.data is None:
-                    with SimpleListItem(route.label):
-                        with List():
-                            for child in route.children:
-                                path = solara.resolve_path(child)
-                                with solara.Link(path):
-                                    title = child.label or "no label"
-                                    if callable(title):
-                                        title = "Error: dynamic title"
-                                    SimpleListItem(title, class_="active" if path == selected else None)
+                    path = solara.resolve_path(route.children[0])
+                    with solara.Link(path):
+                        with SimpleListItem(route.label, class_="active" if path == selected else None):
+                            with List():
+                                for child in route.children[1:]:
+                                    path = solara.resolve_path(child)
+                                    with solara.Link(path):
+                                        title = child.label or "no label"
+                                        if callable(title):
+                                            title = "Error: dynamic title"
+                                        SimpleListItem(title, class_="active" if path == selected else None)
                 else:
                     path = solara.resolve_path(route)
                     with solara.Link(path):
@@ -176,33 +178,37 @@ def Layout(children=[]):
                                 # with rv.Col(md=6, class_="d-flex", style_="justify-content: end"):
                                 #     rv.Btn(elevation=0, large=True, children=["Running App"], color="primary", class_="btn-size--xlarge")
                             # solara.Padding(6)
-                        with rv.Row(children=children):
+                        with rv.Row(children=children, class_="solara-page-content-search"):
                             pass
 
-            # Drawer navigation for sidebar
-            with rv.NavigationDrawer(
-                v_model=show_left_menu,
-                on_v_model=set_show_left_menu,
-                absolute=True,
-                hide_overlay=False,
-                overlay_color="#000000",
-                overlay_opacity=0.5,
-            ):
-                with rv.List(nav=True):
-                    with rv.ListItemGroup(active_class="text--primary"):
-                        for route in all_routes:
-                            with solara.Link(route):
-                                solara.ListItem(route.label)
-
             # Drawer navigation for top menu
             with rv.NavigationDrawer(
                 v_model=show_right_menu,
                 on_v_model=set_show_right_menu,
+                fixed=True,
                 right=True,
-                absolute=True,
                 hide_overlay=False,
                 overlay_color="#000000",
                 overlay_opacity=0.5,
+                style_="height: 100vh",
+            ):
+                with rv.List(nav=True):
+                    with rv.ListItemGroup(active_class="text--primary"):
+                        for route in all_routes:
+                            if route.path == "apps":
+                                continue
+                            with solara.Link(route):
+                                solara.ListItem(route.label)
+
+            # Drawer navigation for sidebar
+            with rv.NavigationDrawer(
+                v_model=show_left_menu,
+                on_v_model=set_show_left_menu,
+                fixed=True,
+                hide_overlay=False,
+                overlay_color="#000000",
+                overlay_opacity=0.5,
+                style_="height: 100vh",
             ):
                 with rv.List(nav=True):
                     current_path = router.path
