@@ -70,6 +70,7 @@ def Sidebar(children=[], level=0):
                     add("image")
                     # add("code")
                     add("sql_code")
+                    add("file_download")
             with ListItem("Status", icon_name="mdi-information"):
                 with List():
                     add("success")
@@ -95,6 +96,7 @@ def Sidebar(children=[], level=0):
                     add("griddraggable")
                     add("gridfixed")
                     add("app_layout")
+                    add("app_bar")
                     add("sidebar")
                     # add("app")
             with ListItem("Data", icon_name="mdi-database"):
@@ -140,12 +142,15 @@ def Sidebar(children=[], level=0):
             with ListItem("Utils", icon_name="mdi-hammer-wrench"):
                 with List():
                     add("memoize")
+                    add("display")
+                    add("widget")
             with ListItem("Advanced", icon_name="mdi-head-cog-outline"):
                 with List():
                     add("style")
                     add("meta")
-            with ListItem("Lab", icon_name="mdi-test-tube"):
+            with ListItem("Cross filter", icon_name="mdi-filter-variant-remove"):
                 with List():
+                    add("cross_filter_dataframe")
                     add("cross_filter_report")
                     add("cross_filter_slider")
                     add("cross_filter_select")
